import java.util.Date;
import java.util.GregorianCalendar;

/**
*<p>Класс Employee, который наследуется от класса Person</p>
* */
public class Employee extends Person {
    private double salary;
    private Date hireDay;

    /**
    * <p>Конструктор класса Employee. Вначале происходит вызов конструтор класса родителя
    * для записи имени сотрудника</p>
    * @param name Имя сотрудника
    * @param salary Заработная плата
    * @param year Год начала работы
    * @param month Месяц начала работы
    * @param day День начала работы
    * */
    public Employee(String name, double salary, int year, int month, int day) {
        super(name);
        this.salary = salary;
        GregorianCalendar calendar = new GregorianCalendar(year, month - 1, day);
        this.hireDay = calendar.getTime();
    }

    /**
    * <p>Функция возвращает заработную плату</p>
    * @return Заработная плата
    * */
    public double getSalary() {
        return salary;
    }

    /**
    * <p>Функция возвращает день устройтва на работу</p>
    * @return День устройтва на работу
    * */
    public Date getHireDay() {
        return hireDay;
    }

    /**
    * <p>Функция предоставляет отчет - какова зарплата сотрудника</p>
    * @return Отчет о заработной плате сотрудника
    * */
    @Override
    public String getDescription() {
        return String.format("an employee with a salary of $%.2f", salary);
    }

    /**
    * <p>Функция для увеличения заработной платы сотрудника на заданое количество процентов</p>
    * @param byPercent Количество процентов
    * */
    public void raiseSalary(double byPercent) {
        double raise = salary * byPercent / 100;
        salary += raise;
    }
}
